HilbertCPCCA
============

.. currentmodule:: xeofs.cross

.. autoclass:: HilbertCPCCA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HilbertCPCCA.__init__
      ~HilbertCPCCA.components
      ~HilbertCPCCA.components_amplitude
      ~HilbertCPCCA.components_phase
      ~HilbertCPCCA.compute
      ~HilbertCPCCA.correlation_coefficients_X
      ~HilbertCPCCA.correlation_coefficients_Y
      ~HilbertCPCCA.cross_correlation_coefficients
      ~HilbertCPCCA.deserialize
      ~HilbertCPCCA.fit
      ~HilbertCPCCA.fraction_variance_X_explained_by_X
      ~HilbertCPCCA.fraction_variance_Y_explained_by_X
      ~HilbertCPCCA.fraction_variance_Y_explained_by_Y
      ~HilbertCPCCA.get_params
      ~HilbertCPCCA.get_serialization_attrs
      ~HilbertCPCCA.heterogeneous_patterns
      ~HilbertCPCCA.homogeneous_patterns
      ~HilbertCPCCA.inverse_transform
      ~HilbertCPCCA.load
      ~HilbertCPCCA.predict
      ~HilbertCPCCA.save
      ~HilbertCPCCA.scores
      ~HilbertCPCCA.scores_amplitude
      ~HilbertCPCCA.scores_phase
      ~HilbertCPCCA.serialize
      ~HilbertCPCCA.squared_covariance_fraction
      ~HilbertCPCCA.transform
   
   

   
   
   